/**
 * This file overrides a couple of functions from the DisplayUtils.js script file
 * supplied with WebMaker 6.
 * This resolves an issue when using the setDateConstraint functionality for fields
 * within a repeating table which meant that the calendar for each constrained field showed the
 * same disabled dates, rather than those of the appropriate field.
 */



/**
 * Gets the calendar object for the field with the given ID
 * If this object has already been created it is just returned,
 * otherwise a new calendar object will be created using the configuration options for this field
 * @param fieldId The ID of the field to get the calendar for.  There must be an entry in the
 *                  hyf.calendar.config array for this field
 * @param repeatId (Optional) If the field we are getting the calendar for is in a repeat, this specifies the repeat id for the
 *                  specific field in the repeat that wants a calendar.
 * @return The CalendarPopup object, or null if one couldn't be created.
 * @private
 * @author Hyfinity Limited
 */
hyf.calendar.getCalendar = function(fieldId, repeatId)
{
    if (typeof(hyf.calendar.config[fieldId]) == 'undefined')
    {
        return null;
    }
    else if (typeof(hyf.calendar.config[fieldId].calendar) != 'undefined')
    {
        //check the calendar was created for this repeat
        if ((typeof(repeatId) == 'undefined') || (repeatId == ''))
        {
            //not in a repeat, so can just use the existing calendar
            return hyf.calendar.config[fieldId].calendar;
        }
        else
        {
            if (repeatId == hyf.calendar.config[fieldId].currentCalendarRepeatId)
            {
                //current calendar is for same repeatId so can return it
                return hyf.calendar.config[fieldId].calendar;
            }
        }
    }

    //need to create a new calendar
    var options = hyf.calendar.config[fieldId];
    var cal;
    if (options.popup == false)
        cal = new CalendarPopup('calendarDiv');
    else
        cal = new CalendarPopup();

    switch (options.type)
    {
        case 'year_select'  :   cal.showYearNavigation();
                                break;
        case 'year_entry'   :   cal.showYearNavigation();
                                cal.showYearNavigationInput();
                                break;
        case 'navigation_dropdowns' :   cal.showNavigationDropdowns();
                                cal.setYearSelectStartOffset(100);
                                break;
    }

    //check the relevant field to try and find contstaint values
    var minExc = options.minExclusive;
    var maxExc = options.maxExclusive;

    var field = document.getElementById(((repeatId) ? repeatId : '') + fieldId);
    if (field != null)
    {
        var val = hyf.util.getWebMakerAttribute(field, 'minExclusive');
        if (val != null)
            minExc = val;
        var val = hyf.util.getWebMakerAttribute(field, 'maxExclusive');
        if (val != null)
            maxExc = val;
    }


    if ((typeof(minExc) != 'undefined') && (minExc != null))
    {
        cal.addDisabledDates(null, convertDate(minExc, options.dataFormat, 'y-M-d'));
    }
    if ((typeof(maxExc) != 'undefined') && (maxExc != null))
    {
        cal.addDisabledDates(convertDate(maxExc, options.dataFormat, 'y-M-d'), null);
    }

    cal.setReturnFunction("hyf.calendar.handleCalendarSelection");

    hyf.calendar.config[fieldId].calendar = cal;

    if ((typeof(repeatId) != 'undefined') && (repeatId != ''))
        hyf.calendar.config[fieldId].currentCalendarRepeatId = repeatId;
    else
        delete hyf.calendar.config[fieldId].currentCalendarRepeatId;

    return hyf.calendar.config[fieldId].calendar;

}

/**
 * Shows the calendar popup for the given field ID.
 * @param fieldId {Field_Name} The ID of the field to show the calendar for.
 * @param repeatId {Repeat_Name} (optional) The repeatId value for the field if it is within a repeat.
 *
 * @author Hyfinity Limited
 */
hyf.calendar.showCalendar = function(fieldId, repeatId)
{
    if (typeof(repeatId) == 'undefined')
        repeatId = '';

    if ((repeatId == '') && (typeof(hyf.calendar.config[fieldId]) == 'undefined'))
    {
        var names = hyf.util.splitFullFieldId(fieldId);
        repeatId = names.repeatId;
        fieldId = names.fieldName;
    }

    var cal = hyf.calendar.getCalendar(fieldId, repeatId);
    if ((cal != null) && (typeof(cal) != 'undefined'))
    {
        if (hyf.calendar.config[fieldId].hasDropDowns)
        {
            var format = hyf.validation.DateValidator.getConcatDateFieldParts(repeatId + fieldId, "format", true);
            var value = hyf.validation.DateValidator.getConcatDateFieldParts(repeatId + fieldId, "values", true);
            var preset = '';
            if ((format != '') && (value != ''))
            {
                preset = convertDate(value, format, 'y-M-d');
            }
            cal.showCalendar(repeatId + fieldId + '_calendar_anchor', preset);
        }
        else
        {
            var field = document.getElementById(repeatId + fieldId);
            var preset = ''
            if (field.value != '')
            {
                var format = field.getAttribute('_display_date_format');
                if (format == null)
                    format = field.getAttribute('_data_date_format');
                preset = convertDate(field.value, format, 'y-M-d');
            }
            cal.showCalendar(repeatId + fieldId + '_calendar_anchor', preset);
        }
    }
    hyf.calendar.activeFieldId = fieldId;
    hyf.calendar.activeFieldRepeatId = repeatId;
}